pub struct BalanceStartCommand {
pub data_filters: Option<String>,
pub metadata_filters: Option<String>,
pub system_filters: Option<String>,
pub force: bool,
pub full_balance: bool,
pub background: bool,
pub enqueue: bool,
pub path: PathBuf,
}Expand description
Balance chunks across the devices
Balance and/or convert (change allocation profile of) chunks that passed all filters in a comma-separated list of filters for a particular chunk type. If filter list is not given balance all chunks of that type. In case none of the -d, -m or -s options is given balance all chunks in a filesystem. This is potentially long operation and the user is warned before this start, with a delay to stop it.
Fields
data_filters: Option<String>Act on data chunks with optional filters
metadata_filters: Option<String>Act on metadata chunks with optional filters
system_filters: Option<String>Act on system chunks (requires force) with optional filters
force: boolForce a reduction of metadata integrity, or skip timeout when converting to RAID56 profiles
full_balance: boolDo not print warning and do not delay start
background: boolRun the balance as a background process
enqueue: boolWait if there’s another exclusive operation running, otherwise continue
path: PathBufTrait Implementations
Sourceimpl Args for BalanceStartCommand
impl Args for BalanceStartCommand
Sourcefn augment_args<'b>(__clap_app: Command) -> Command
fn augment_args<'b>(__clap_app: Command) -> Command
Sourcefn augment_args_for_update<'b>(__clap_app: Command) -> Command
fn augment_args_for_update<'b>(__clap_app: Command) -> Command
Command so it can instantiate self via
FromArgMatches::update_from_arg_matches_mut Read moreSourceimpl CommandFactory for BalanceStartCommand
impl CommandFactory for BalanceStartCommand
Sourceimpl Debug for BalanceStartCommand
impl Debug for BalanceStartCommand
Sourceimpl FromArgMatches for BalanceStartCommand
impl FromArgMatches for BalanceStartCommand
Sourcefn from_arg_matches(__clap_arg_matches: &ArgMatches) -> Result<Self, Error>
fn from_arg_matches(__clap_arg_matches: &ArgMatches) -> Result<Self, Error>
Sourcefn from_arg_matches_mut(
__clap_arg_matches: &mut ArgMatches,
) -> Result<Self, Error>
fn from_arg_matches_mut( __clap_arg_matches: &mut ArgMatches, ) -> Result<Self, Error>
Sourcefn update_from_arg_matches(
&mut self,
__clap_arg_matches: &ArgMatches,
) -> Result<(), Error>
fn update_from_arg_matches( &mut self, __clap_arg_matches: &ArgMatches, ) -> Result<(), Error>
ArgMatches to self.Sourcefn update_from_arg_matches_mut(
&mut self,
__clap_arg_matches: &mut ArgMatches,
) -> Result<(), Error>
fn update_from_arg_matches_mut( &mut self, __clap_arg_matches: &mut ArgMatches, ) -> Result<(), Error>
ArgMatches to self.