pub struct CheckCommand { /* private fields */ }Expand description
Check structural integrity of a filesystem (unmounted).
Verify the integrity of a btrfs filesystem by checking internal structures, extent trees, and data checksums. The filesystem must be unmounted before running this command. This is a potentially slow operation that requires CAP_SYS_ADMIN. Use –readonly to perform checks without attempting repairs.