pub struct DeviceAddCommand {
pub force: bool,
pub nodiscard: bool,
pub enqueue: bool,
pub devices: Vec<PathBuf>,
pub target: PathBuf,
}Expand description
Add one or more devices to a mounted filesystem
The device must not be mounted and should not contain a filesystem or other data. The operation requires CAP_SYS_ADMIN.
Fields
force: boolForce overwrite of an existing filesystem on the device
nodiscard: boolDo not perform whole device TRIM (discard) before adding
enqueue: boolWait if there’s another exclusive operation running, instead of returning an error
devices: Vec<PathBuf>One or more block devices to add
target: PathBufMount point of the target filesystem