pub struct DeviceScanCommand {
pub forget: bool,
pub devices: Vec<PathBuf>,
}Expand description
Scan or unregister devices for multi-device btrfs filesystems
Without –forget, registers each given device with the kernel so that multi-device filesystems can be assembled and mounted.
With –forget, unregisters the given devices (or all stale devices if none are specified) so the kernel no longer tracks them.
Fields
forget: boolUnregister devices instead of registering them.
If no devices are given, all devices that are not part of a currently mounted filesystem are unregistered.
devices: Vec<PathBuf>Block devices to scan or unregister