DeviceUsageCommand

Struct DeviceUsageCommand 

pub struct DeviceUsageCommand {
    pub paths: Vec<PathBuf>,
    pub raw: bool,
    pub human_readable: bool,
    pub human_base1000: bool,
    pub iec: bool,
    pub si: bool,
    pub kbytes: bool,
    pub mbytes: bool,
    pub gbytes: bool,
    pub tbytes: bool,
}
Show detailed information about internal allocations in devices

For each device, prints the total device size, the “slack” (difference between the physical block device size and the size btrfs uses), per-profile chunk allocations (Data, Metadata, System), and unallocated space. Requires CAP_SYS_ADMIN for the chunk tree walk.

Fields

paths: Vec<PathBuf>

Path(s) to a mounted btrfs filesystem

raw: bool

Show raw numbers in bytes

human_readable: bool

Show human-friendly numbers using base 1024 (default)

human_base1000: bool

Show human-friendly numbers using base 1000

iec: bool

Use 1024 as a base (KiB, MiB, GiB, TiB)

si: bool

Use 1000 as a base (kB, MB, GB, TB)

kbytes: bool

Show sizes in KiB, or kB with –si

mbytes: bool

Show sizes in MiB, or MB with –si

gbytes: bool

Show sizes in GiB, or GB with –si

tbytes: bool

Show sizes in TiB, or TB with –si