pub struct FilesystemResizeCommand {
pub enqueue: bool,
pub offline: bool,
pub size: String,
pub path: PathBuf,
}Expand description
Resize a mounted btrfs filesystem
Fields
enqueue: boolWait if there is another exclusive operation running, otherwise error
offline: boolResize a filesystem stored in a file image (unmounted)
size: StringNew size for the filesystem, e.g. “1G”, “+512M”, “-1G”, “max”, “cancel”, or “devid:ID:SIZE” to target a specific device
path: PathBufTrait Implementations
Sourceimpl Args for FilesystemResizeCommand
impl Args for FilesystemResizeCommand
Sourcefn augment_args<'b>(__clap_app: Command) -> Command
fn augment_args<'b>(__clap_app: Command) -> Command
Sourcefn augment_args_for_update<'b>(__clap_app: Command) -> Command
fn augment_args_for_update<'b>(__clap_app: Command) -> Command
Append to
Command so it can instantiate self via
FromArgMatches::update_from_arg_matches_mut Read moreSourceimpl Debug for FilesystemResizeCommand
impl Debug for FilesystemResizeCommand
Sourceimpl FromArgMatches for FilesystemResizeCommand
impl FromArgMatches for FilesystemResizeCommand
Sourcefn from_arg_matches(__clap_arg_matches: &ArgMatches) -> Result<Self, Error>
fn from_arg_matches(__clap_arg_matches: &ArgMatches) -> Result<Self, Error>
Sourcefn from_arg_matches_mut(
__clap_arg_matches: &mut ArgMatches,
) -> Result<Self, Error>
fn from_arg_matches_mut( __clap_arg_matches: &mut ArgMatches, ) -> Result<Self, Error>
Sourcefn update_from_arg_matches(
&mut self,
__clap_arg_matches: &ArgMatches,
) -> Result<(), Error>
fn update_from_arg_matches( &mut self, __clap_arg_matches: &ArgMatches, ) -> Result<(), Error>
Assign values from
ArgMatches to self.Sourcefn update_from_arg_matches_mut(
&mut self,
__clap_arg_matches: &mut ArgMatches,
) -> Result<(), Error>
fn update_from_arg_matches_mut( &mut self, __clap_arg_matches: &mut ArgMatches, ) -> Result<(), Error>
Assign values from
ArgMatches to self.Sourceimpl Parser for FilesystemResizeCommand
impl Parser for FilesystemResizeCommand
Sourcefn parse_from<I, T>(itr: I) -> Self
fn parse_from<I, T>(itr: I) -> Self
Parse from iterator, exit on error.
Sourcefn try_parse_from<I, T>(itr: I) -> Result<Self, Error>
fn try_parse_from<I, T>(itr: I) -> Result<Self, Error>
Parse from iterator, return Err on error.
Sourcefn update_from<I, T>(&mut self, itr: I)
fn update_from<I, T>(&mut self, itr: I)