pub struct MinDevSizeCommand {
pub offline: bool,
/* private fields */
}Expand description
Print the minimum size a device can be shrunk to.
Returns the minimum size in bytes that the specified device can be resized to without losing data. The device id 1 is used by default. Requires CAP_SYS_ADMIN (unless –offline is used).
Fields
offline: boolRead directly from an unmounted device or image file instead of a mounted filesystem. Does not require CAP_SYS_ADMIN.