pub struct PropertyCommand {
pub subcommand: PropertySubcommand,
}Expand description
Modify properties of filesystem objects.
Get, set, and list properties of filesystem objects including subvolumes, inodes, the filesystem itself, and devices. Properties control various aspects of filesystem behavior such as read-only status, compression, and labels. Most property operations require CAP_SYS_ADMIN or appropriate filesystem permissions.
Fields
subcommand: PropertySubcommandTrait Implementations
Sourceimpl Args for PropertyCommand
impl Args for PropertyCommand
Sourcefn augment_args<'b>(__clap_app: Command) -> Command
fn augment_args<'b>(__clap_app: Command) -> Command
Sourcefn augment_args_for_update<'b>(__clap_app: Command) -> Command
fn augment_args_for_update<'b>(__clap_app: Command) -> Command
Append to
Command so it can instantiate self via
FromArgMatches::update_from_arg_matches_mut Read moreSourceimpl CommandFactory for PropertyCommand
impl CommandFactory for PropertyCommand
Sourceimpl CommandGroup for PropertyCommand
impl CommandGroup for PropertyCommand
Sourceimpl Debug for PropertyCommand
impl Debug for PropertyCommand
Sourceimpl FromArgMatches for PropertyCommand
impl FromArgMatches for PropertyCommand
Sourcefn from_arg_matches(__clap_arg_matches: &ArgMatches) -> Result<Self, Error>
fn from_arg_matches(__clap_arg_matches: &ArgMatches) -> Result<Self, Error>
Sourcefn from_arg_matches_mut(
__clap_arg_matches: &mut ArgMatches,
) -> Result<Self, Error>
fn from_arg_matches_mut( __clap_arg_matches: &mut ArgMatches, ) -> Result<Self, Error>
Sourcefn update_from_arg_matches(
&mut self,
__clap_arg_matches: &ArgMatches,
) -> Result<(), Error>
fn update_from_arg_matches( &mut self, __clap_arg_matches: &ArgMatches, ) -> Result<(), Error>
Assign values from
ArgMatches to self.Sourcefn update_from_arg_matches_mut(
&mut self,
__clap_arg_matches: &mut ArgMatches,
) -> Result<(), Error>
fn update_from_arg_matches_mut( &mut self, __clap_arg_matches: &mut ArgMatches, ) -> Result<(), Error>
Assign values from
ArgMatches to self.Sourceimpl Parser for PropertyCommand
impl Parser for PropertyCommand
Sourcefn parse_from<I, T>(itr: I) -> Self
fn parse_from<I, T>(itr: I) -> Self
Parse from iterator, exit on error.
Sourcefn try_parse_from<I, T>(itr: I) -> Result<Self, Error>
fn try_parse_from<I, T>(itr: I) -> Result<Self, Error>
Parse from iterator, return Err on error.
Sourcefn update_from<I, T>(&mut self, itr: I)
fn update_from<I, T>(&mut self, itr: I)