pub struct ReceiveCommand { /* private fields */ }Expand description
Receive subvolumes from a stream.
Read a btrfs send stream and recreate subvolumes on the destination filesystem. Streams can be received incrementally based on a parent subvolume to only apply changes. Multiple streams can be received in sequence. The destination filesystem must be mounted and writable. Requires CAP_SYS_ADMIN.