pub struct ReplaceCancelCommand {
pub mount_point: PathBuf,
}Expand description
Cancel a running device replace operation.
If a replace operation is in progress on the filesystem mounted at mount_point, it is cancelled. The target device is left in an undefined state and should not be used further without reformatting.
Fields
mount_point: PathBufPath to the mounted btrfs filesystem