pub struct ReplaceStartCommand {
pub source: String,
pub target: PathBuf,
pub mount_point: PathBuf,
pub redundancy_only: bool,
pub force: bool,
pub no_background: bool,
pub enqueue: bool,
pub nodiscard: bool,
}Expand description
Replace a device in the filesystem.
The source device can be specified either as a path (e.g. /dev/sdb) or as a numeric device ID. The target device will be used to replace the source. The filesystem must be mounted at mount_point.
Fields
source: StringSource device path or devid to replace
target: PathBufTarget device that will replace the source
mount_point: PathBufMount point of the filesystem
redundancy_only: boolOnly read from srcdev if no other zero-defect mirror exists
force: boolForce using and overwriting targetdev even if it contains a valid btrfs filesystem
no_background: boolDo not background the replace operation; wait for it to finish
enqueue: boolWait if there’s another exclusive operation running, instead of returning an error
nodiscard: boolDo not perform whole device TRIM on the target device