pub struct ReplaceStatusCommand {
pub once: bool,
pub mount_point: PathBuf,
}Expand description
Print status of a running device replace operation.
Without -1 the status is printed continuously until the replace operation finishes or is cancelled. With -1 the status is printed once and the command exits.
Fields
once: boolPrint once instead of continuously until the replace finishes
mount_point: PathBufPath to a mounted btrfs filesystem