pub struct RescueClearUuidTreeCommand { /* private fields */ }Expand description
Delete uuid tree so that kernel can rebuild it at mount time
The UUID tree maps subvolume UUIDs to their root IDs. If it becomes corrupted it can prevent mount or cause subvolume lookup failures. Deleting it is safe because the kernel rebuilds it automatically on the next mount.
The device must not be mounted.