RescueZeroLogCommand

Struct RescueZeroLogCommand 

pub struct RescueZeroLogCommand { /* private fields */ }
Clear the tree log (usable if it’s corrupted and prevents mount)

The log tree is used for fsync durability. If it becomes corrupted it can prevent the filesystem from mounting. Clearing it forces a full fsync of all previously synced data on the next mount. No data is lost — only the durability guarantee of uncommitted fsyncs.

The device must not be mounted.