pub struct ScrubStartCommand {
pub no_background: bool,
pub device: bool,
pub readonly: bool,
pub raw: bool,
pub force: bool,
pub limit: Option<u64>,
pub ioprio_class: Option<i32>,
pub ioprio_classdata: Option<i32>,
pub path: PathBuf,
}Expand description
Start a new scrub on the filesystem or a device.
Scrubs all devices sequentially. This command blocks until the scrub completes; use Ctrl-C to cancel.
Fields
no_background: boolDo not background (default behavior, accepted for compatibility)
device: boolStats per device
readonly: boolRead-only mode: check for errors but do not attempt repairs
raw: boolPrint full raw data instead of summary
force: boolForce starting new scrub even if a scrub is already running
limit: Option<u64>Set the throughput limit for each device (0 for unlimited), restored afterwards
ioprio_class: Option<i32>Set ioprio class (see ionice(1) manpage)
ioprio_classdata: Option<i32>Set ioprio classdata (see ionice(1) manpage)
path: PathBufPath to a mounted btrfs filesystem or a device