pub struct ScrubStatusCommand {
pub device: bool,
pub raw_data: bool,
pub units: UnitMode,
pub path: PathBuf,
}Expand description
Show the status of a running or finished scrub
Fields
device: boolShow stats per device
raw_data: boolPrint full raw data instead of summary
units: UnitModepath: PathBufPath to a mounted btrfs filesystem or a device