pub struct SubvolumeCommand {
pub subcommand: SubvolumeSubcommand,
}Expand description
Create, delete, list, and manage btrfs subvolumes and snapshots.
Subvolumes are independent filesystem trees within a btrfs filesystem, allowing flexible storage organization, snapshots, and quota management. Snapshots are read-only or read-write copies of subvolumes at a point in time. Most operations require CAP_SYS_ADMIN.
Fields
subcommand: SubvolumeSubcommandTrait Implementations
Sourceimpl Args for SubvolumeCommand
impl Args for SubvolumeCommand
Sourcefn augment_args<'b>(__clap_app: Command) -> Command
fn augment_args<'b>(__clap_app: Command) -> Command
Sourcefn augment_args_for_update<'b>(__clap_app: Command) -> Command
fn augment_args_for_update<'b>(__clap_app: Command) -> Command
Append to
Command so it can instantiate self via
FromArgMatches::update_from_arg_matches_mut Read moreSourceimpl CommandFactory for SubvolumeCommand
impl CommandFactory for SubvolumeCommand
Sourceimpl Debug for SubvolumeCommand
impl Debug for SubvolumeCommand
Sourceimpl FromArgMatches for SubvolumeCommand
impl FromArgMatches for SubvolumeCommand
Sourcefn from_arg_matches(__clap_arg_matches: &ArgMatches) -> Result<Self, Error>
fn from_arg_matches(__clap_arg_matches: &ArgMatches) -> Result<Self, Error>
Sourcefn from_arg_matches_mut(
__clap_arg_matches: &mut ArgMatches,
) -> Result<Self, Error>
fn from_arg_matches_mut( __clap_arg_matches: &mut ArgMatches, ) -> Result<Self, Error>
Sourcefn update_from_arg_matches(
&mut self,
__clap_arg_matches: &ArgMatches,
) -> Result<(), Error>
fn update_from_arg_matches( &mut self, __clap_arg_matches: &ArgMatches, ) -> Result<(), Error>
Assign values from
ArgMatches to self.Sourcefn update_from_arg_matches_mut(
&mut self,
__clap_arg_matches: &mut ArgMatches,
) -> Result<(), Error>
fn update_from_arg_matches_mut( &mut self, __clap_arg_matches: &mut ArgMatches, ) -> Result<(), Error>
Assign values from
ArgMatches to self.Sourceimpl Parser for SubvolumeCommand
impl Parser for SubvolumeCommand
Sourcefn parse_from<I, T>(itr: I) -> Self
fn parse_from<I, T>(itr: I) -> Self
Parse from iterator, exit on error.
Sourcefn try_parse_from<I, T>(itr: I) -> Result<Self, Error>
fn try_parse_from<I, T>(itr: I) -> Result<Self, Error>
Parse from iterator, return Err on error.
Sourcefn update_from<I, T>(&mut self, itr: I)
fn update_from<I, T>(&mut self, itr: I)