pub struct SubvolumeCreateCommand {
pub qgroups: Vec<String>,
pub parents: bool,
pub paths: Vec<PathBuf>,
}Expand description
Create a new subvolume at each given path.
The parent directory must already exist and be on a btrfs filesystem (unless -p is given). Requires CAP_SYS_ADMIN.
Fields
qgroups: Vec<String>Add the newly created subvolume to a qgroup (can be given multiple times)
parents: boolCreate any missing parent directories (like mkdir -p)
paths: Vec<PathBuf>Trait Implementations
Sourceimpl Args for SubvolumeCreateCommand
impl Args for SubvolumeCreateCommand
Sourcefn augment_args<'b>(__clap_app: Command) -> Command
fn augment_args<'b>(__clap_app: Command) -> Command
Sourcefn augment_args_for_update<'b>(__clap_app: Command) -> Command
fn augment_args_for_update<'b>(__clap_app: Command) -> Command
Append to
Command so it can instantiate self via
FromArgMatches::update_from_arg_matches_mut Read moreSourceimpl Debug for SubvolumeCreateCommand
impl Debug for SubvolumeCreateCommand
Sourceimpl FromArgMatches for SubvolumeCreateCommand
impl FromArgMatches for SubvolumeCreateCommand
Sourcefn from_arg_matches(__clap_arg_matches: &ArgMatches) -> Result<Self, Error>
fn from_arg_matches(__clap_arg_matches: &ArgMatches) -> Result<Self, Error>
Sourcefn from_arg_matches_mut(
__clap_arg_matches: &mut ArgMatches,
) -> Result<Self, Error>
fn from_arg_matches_mut( __clap_arg_matches: &mut ArgMatches, ) -> Result<Self, Error>
Sourcefn update_from_arg_matches(
&mut self,
__clap_arg_matches: &ArgMatches,
) -> Result<(), Error>
fn update_from_arg_matches( &mut self, __clap_arg_matches: &ArgMatches, ) -> Result<(), Error>
Assign values from
ArgMatches to self.Sourcefn update_from_arg_matches_mut(
&mut self,
__clap_arg_matches: &mut ArgMatches,
) -> Result<(), Error>
fn update_from_arg_matches_mut( &mut self, __clap_arg_matches: &mut ArgMatches, ) -> Result<(), Error>
Assign values from
ArgMatches to self.Sourceimpl Parser for SubvolumeCreateCommand
impl Parser for SubvolumeCreateCommand
Sourcefn parse_from<I, T>(itr: I) -> Self
fn parse_from<I, T>(itr: I) -> Self
Parse from iterator, exit on error.
Sourcefn try_parse_from<I, T>(itr: I) -> Result<Self, Error>
fn try_parse_from<I, T>(itr: I) -> Result<Self, Error>
Parse from iterator, return Err on error.
Sourcefn update_from<I, T>(&mut self, itr: I)
fn update_from<I, T>(&mut self, itr: I)