pub struct SubvolumeDeleteCommand {
pub commit_after: bool,
pub commit_each: bool,
pub subvolid: Option<u64>,
pub recursive: bool,
pub paths: Vec<PathBuf>,
}Expand description
Delete one or more subvolumes or snapshots.
Delete subvolumes from the filesystem, specified by path or id. The corresponding directory is removed instantly but the data blocks are removed later.
The deletion does not involve full commit by default due to performance reasons (as a consequence, the subvolume may appear again after a crash). Use one of the –commit options to wait until the operation is safely stored on the media.
Fields
commit_after: boolWait for transaction commit at the end of the operation
commit_each: boolWait for transaction commit after deleting each subvolume
subvolid: Option<u64>Delete by subvolume ID instead of path. When used, exactly one positional argument is expected: the filesystem path (mount point).
recursive: boolDelete accessible subvolumes beneath each subvolume recursively. This is not atomic and may need root to delete subvolumes not accessible by the user.
paths: Vec<PathBuf>Subvolume paths to delete, or (with –subvolid) the filesystem path