pub struct SubvolumeShowCommand {
pub rootid: Option<u64>,
pub uuid: Option<ParsedUuid>,
pub units: UnitMode,
pub path: PathBuf,
}Expand description
Show detailed information about a subvolume
Displays UUIDs, generation numbers, creation time, flags, and send/receive transaction IDs for the subvolume that contains the given path.
The subvolume can be specified by path (default), or by root id or UUID that are looked up relative to the given path.
Fields
rootid: Option<u64>Look up subvolume by its root ID instead of path
uuid: Option<ParsedUuid>Look up subvolume by its UUID instead of path
units: UnitModepath: PathBufPath to a subvolume or any file within it