pub struct SubvolumeSyncCommand { /* private fields */ }Expand description
Wait until given subvolume(s) are completely removed from the filesystem
Wait until given subvolume(s) are completely removed from the filesystem after deletion. If no subvolume id is given, wait until all current deletion requests are completed, but do not wait for subvolumes deleted meanwhile. The status of subvolume ids is checked periodically.