pub struct UnitMode {
pub raw: bool,
pub human_readable: bool,
pub iec: bool,
pub si: bool,
pub kbytes: bool,
pub mbytes: bool,
pub gbytes: bool,
pub tbytes: bool,
}Expand description
Unit display mode flags, shared by subcommands that output sizes.
Control how sizes are displayed in output. By default, human-readable format with base 1024 (KiB, MiB, GiB, TiB) is used. You can specify exact units or enable base 1000 (kB, MB, GB, TB) with –si.
Fields
raw: boolShow raw numbers in bytes
human_readable: boolShow human-friendly numbers using base 1024 (default)
iec: boolUse 1024 as a base (KiB, MiB, GiB, TiB)
si: boolUse 1000 as a base (kB, MB, GB, TB)
kbytes: boolShow sizes in KiB, or kB with –si
mbytes: boolShow sizes in MiB, or MB with –si
gbytes: boolShow sizes in GiB, or GB with –si
tbytes: boolShow sizes in TiB, or TB with –si
Implementations