pub struct DeviceStatsCommand {
pub check: bool,
pub reset: bool,
pub path: PathBuf,
}Expand description
Show device I/O error statistics for all devices of a filesystem
Reads per-device counters for write, read, flush, corruption, and generation errors. The path can be a mount point or a device belonging to the filesystem.
The operation requires CAP_SYS_ADMIN.
Fields
check: boolReturn a non-zero exit code if any error counter is greater than zero
reset: boolPrint current values and then atomically reset all counters to zero
path: PathBufPath to a mounted btrfs filesystem or one of its devices