pub struct DeviceUsageCommand {
pub paths: Vec<PathBuf>,
pub raw: bool,
pub human_readable: bool,
pub human_base1000: bool,
pub iec: bool,
pub si: bool,
pub kbytes: bool,
pub mbytes: bool,
pub gbytes: bool,
pub tbytes: bool,
}Expand description
Show detailed information about internal allocations in devices
For each device, prints the total device size, the “slack” (difference between the physical block device size and the size btrfs uses), per-profile chunk allocations (Data, Metadata, System), and unallocated space. Requires CAP_SYS_ADMIN for the chunk tree walk.
Fields
paths: Vec<PathBuf>Path(s) to a mounted btrfs filesystem
raw: boolShow raw numbers in bytes
human_readable: boolShow human-friendly numbers using base 1024 (default)
human_base1000: boolShow human-friendly numbers using base 1000
iec: boolUse 1024 as a base (KiB, MiB, GiB, TiB)
si: boolUse 1000 as a base (kB, MB, GB, TB)
kbytes: boolShow sizes in KiB, or kB with –si
mbytes: boolShow sizes in MiB, or MB with –si
gbytes: boolShow sizes in GiB, or GB with –si
tbytes: boolShow sizes in TiB, or TB with –si