pub struct InspectCommand {
pub subcommand: InspectSubcommand,
}Expand description
Query various internal filesystem information.
Access advanced information about filesystem internals including inode resolution, logical extent to physical block mapping, subvolume IDs, chunk layout, and other diagnostic data. These commands are primarily useful for debugging, analysis, and recovery operations. Most operations require CAP_SYS_ADMIN.
Fields
subcommand: InspectSubcommandTrait Implementations
Sourceimpl Args for InspectCommand
impl Args for InspectCommand
Sourcefn augment_args<'b>(__clap_app: Command) -> Command
fn augment_args<'b>(__clap_app: Command) -> Command
Sourcefn augment_args_for_update<'b>(__clap_app: Command) -> Command
fn augment_args_for_update<'b>(__clap_app: Command) -> Command
Append to
Command so it can instantiate self via
FromArgMatches::update_from_arg_matches_mut Read moreSourceimpl CommandFactory for InspectCommand
impl CommandFactory for InspectCommand
Sourceimpl Debug for InspectCommand
impl Debug for InspectCommand
Sourceimpl FromArgMatches for InspectCommand
impl FromArgMatches for InspectCommand
Sourcefn from_arg_matches(__clap_arg_matches: &ArgMatches) -> Result<Self, Error>
fn from_arg_matches(__clap_arg_matches: &ArgMatches) -> Result<Self, Error>
Sourcefn from_arg_matches_mut(
__clap_arg_matches: &mut ArgMatches,
) -> Result<Self, Error>
fn from_arg_matches_mut( __clap_arg_matches: &mut ArgMatches, ) -> Result<Self, Error>
Sourcefn update_from_arg_matches(
&mut self,
__clap_arg_matches: &ArgMatches,
) -> Result<(), Error>
fn update_from_arg_matches( &mut self, __clap_arg_matches: &ArgMatches, ) -> Result<(), Error>
Assign values from
ArgMatches to self.Sourcefn update_from_arg_matches_mut(
&mut self,
__clap_arg_matches: &mut ArgMatches,
) -> Result<(), Error>
fn update_from_arg_matches_mut( &mut self, __clap_arg_matches: &mut ArgMatches, ) -> Result<(), Error>
Assign values from
ArgMatches to self.Sourceimpl Parser for InspectCommand
impl Parser for InspectCommand
Sourcefn parse_from<I, T>(itr: I) -> Self
fn parse_from<I, T>(itr: I) -> Self
Parse from iterator, exit on error.
Sourcefn try_parse_from<I, T>(itr: I) -> Result<Self, Error>
fn try_parse_from<I, T>(itr: I) -> Result<Self, Error>
Parse from iterator, return Err on error.
Sourcefn update_from<I, T>(&mut self, itr: I)
fn update_from<I, T>(&mut self, itr: I)