pub struct SendCommand { /* private fields */ }Expand description
Send the subvolume(s) to stdout.
Generate a stream representation of one or more subvolumes that can be transmitted over the network or stored for later restoration. Streams are incremental and can be based on a parent subvolume to only send changes. The stream output is in btrfs send format and can be received with the receive command. Requires CAP_SYS_ADMIN.