pub struct SubvolumeFindNewCommand { /* private fields */ }Expand description
List the recently modified files in a subvolume
Prints all files that have been modified since the given generation number.
The generation can be found with btrfs subvolume show.