UnitMode

Struct UnitMode 

pub struct UnitMode {
    pub raw: bool,
    pub human_readable: bool,
    pub iec: bool,
    pub si: bool,
    pub kbytes: bool,
    pub mbytes: bool,
    pub gbytes: bool,
    pub tbytes: bool,
}
Unit display mode flags, shared by subcommands that output sizes.

Control how sizes are displayed in output. By default, human-readable format with base 1024 (KiB, MiB, GiB, TiB) is used. You can specify exact units or enable base 1000 (kB, MB, GB, TB) with –si.

Fields

raw: bool

Show raw numbers in bytes

human_readable: bool

Show human-friendly numbers using base 1024 (default)

iec: bool

Use 1024 as a base (KiB, MiB, GiB, TiB)

si: bool

Use 1000 as a base (kB, MB, GB, TB)

kbytes: bool

Show sizes in KiB, or kB with –si

mbytes: bool

Show sizes in MiB, or MB with –si

gbytes: bool

Show sizes in GiB, or GB with –si

tbytes: bool

Show sizes in TiB, or TB with –si