pub trait CommandGroup {
// Required method
fn leaf(&self) -> &dyn Runnable;
}Expand description
A command group that delegates to a leaf subcommand.
Implement this for parent commands (e.g. BalanceCommand,
DeviceCommand) that simply dispatch to their subcommand.
A blanket Runnable impl forwards all methods through leaf().
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".